<?php
    class Articoli{
        // Connessione
        private $conn;
        // Tabella
        private $db_table = "articoli";
        // Colonne
        public $id;
        public $codice;
        public $descrizione;
        public $quantita;
        public $created;
        public $updated;
        // Connessione al database
        public function __construct($db){
            $this->conn = $db;
        }
        // Legge tutti gli articoli
        public function getArticoli(){
            $sqlQuery = "SELECT id, codice, descrizione, quantita, created, updated FROM " . $this->db_table . "";
            $stmt = $this->conn->prepare($sqlQuery);
            $stmt->execute();
            return $stmt;
        }
        // Inserisce un articolo
        public function createArticolo(){
            $sqlQuery = "INSERT INTO
                        ". $this->db_table ."
                    SET
                        codice = :codice, 
                        descrizione = :descrizione, 
                        quantita = :quantita, 
                        created = :created, 
                        updated = :updated";
        
            $stmt = $this->conn->prepare($sqlQuery);
        
            // Converte i tag HTML in testo
            $this->codice=htmlspecialchars(strip_tags($this->codice));
            $this->descrizione=htmlspecialchars(strip_tags($this->descrizione));
            $this->quantita=htmlspecialchars(strip_tags($this->quantita));
            $this->created=htmlspecialchars(strip_tags($this->created));
            $this->updated=htmlspecialchars(strip_tags($this->updated));
        
            // bind data
            $stmt->bindParam(":codice", $this->codice);
            $stmt->bindParam(":descrizione", $this->descrizione);
            $stmt->bindParam(":quantita", $this->quantita);
            $stmt->bindParam(":created", $this->created);
            $stmt->bindParam(":updated", $this->updated);
        
            if($stmt->execute()){
			   $this->id = $this->conn->lastInsertId();
               return true;
            }
            return false;
        }
        // Legge un articolo
        public function getArticolo(){
            $sqlQuery = "SELECT
                        id, 
                        codice, 
                        descrizione, 
                        quantita, 
                        created, 
                        updated
                      FROM
                        ". $this->db_table ."
                    WHERE 
                       id = ?
                    LIMIT 0,1";
            $stmt = $this->conn->prepare($sqlQuery);
            $stmt->bindParam(1, $this->id);
            $stmt->execute();
            $dataRow = $stmt->fetch(PDO::FETCH_ASSOC);
			if ($dataRow) {
				$this->codice = $dataRow['codice'];
				$this->descrizione = $dataRow['descrizione'];
				$this->quantita = $dataRow['quantita'];
				$this->created = $dataRow['created'];
				$this->updated = $dataRow['updated'];
			}
        }
        // Aggiorna un articolo
        public function updateArticolo(){
            $sqlQuery = "UPDATE
                        ". $this->db_table ."
                    SET
                        codice = :codice, 
                        descrizione = :descrizione, 
                        quantita = :quantita, 
                        updated = :updated
                    WHERE 
                        id = :id";
        
            $stmt = $this->conn->prepare($sqlQuery);
        
            $this->codice=htmlspecialchars(strip_tags($this->codice));
            $this->descrizione=htmlspecialchars(strip_tags($this->descrizione));
            $this->quantita=htmlspecialchars(strip_tags($this->quantita));
            $this->updated=htmlspecialchars(strip_tags($this->updated));
            $this->id=htmlspecialchars(strip_tags($this->id));
        
            // Binding dei dati
            $stmt->bindParam(":codice", $this->codice);
            $stmt->bindParam(":descrizione", $this->descrizione);
            $stmt->bindParam(":quantita", $this->quantita);
            $stmt->bindParam(":updated", $this->updated);
            $stmt->bindParam(":id", $this->id);
        
            if($stmt->execute()){
               return true;
            }
            return false;
        }
        // Cancella un articolo
        function deleteArticolo(){
            $sqlQuery = "DELETE FROM " . $this->db_table . " WHERE id = ?";
            $stmt = $this->conn->prepare($sqlQuery);
        
            $this->id=htmlspecialchars(strip_tags($this->id));
        
            $stmt->bindParam(1, $this->id);
        
            if($stmt->execute()){
                return true;
            }
            return false;
        }
    }
?>